==> babel-plugin-lib-import-1.0.0.tgz: package/README.md <==
# babel-plugin-lib-import

一个能实现按需引入lib文件的babel插件。

[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://commitizen.github.io/cz-cli/)

## lib类似下面的结构

```
|-- libName
    |-- lib                         // 构建后的目录
    |   |-- index.js                // package.json指定的入口文件
    |   |-- components
    |   |   |-- city-picker
    |   |   |   |-- index.js
    |   |   |-- cutover
    |   |   |   |-- index.js
    |   |   |   |-- style
    |   |   |       |-- default.js  // 样式文件，引入即可，不需要做任何处理
    |   |   |       |-- custom.js
    |   |   |-- dialog
    |   |   |   |-- index.js
    |   |   |   |-- style
    |   |   |       |-- default.js
    |   |   |       |-- custom.js
    |   |-- tools
    |       |-- easing
    |       |   |-- index.js
    |       |-- prefix
    |       |   |-- index.js
    |-- src
        |-- index.js
        |-- components
        |   |-- city-picker
        |   |   |-- README.md
        |   |   |-- index.vue
        |   |-- cutover
        |   |   |-- README.md
        |   |   |-- index.vue
        |   |   |-- style
        |   |       |-- default.less
        |   |-- dialog
        |   |   |-- README.md
        |   |   |-- index.vue
        |   |   |-- style
        |   |       |-- default.less
        |-- tools
            |-- easing
            |   |-- README.md
            |   |-- index.js        // export多个变量
            |-- prefix
            |   |-- README.md
            |   |-- index.js

```

## 工作原理

```
import { Dialog, Cutover, SineEaseIn, SineEaseOut } from 'libName'
```

会被转换成

```
import { default as Dialog } from '/xxx/xx/libName/lib/components/dialog/index.js'
import { default as Cutover } from '/xxx/xx/libName/lib/components/cutover/index.js'
import { SineEaseIn, SineEaseOut } from '/xxx/xx/libName/lib/tools/easing/index.js'
import '/xxx/xx/libName/lib/components/dialog/style/default.js'
import '/xxx/xx/libName/lib/components/cutover/style/default.js'
```

插件会从lib的package.json里找到入口文件，并解析入口文件获取相关的import、export信息，然后跟项目中用到的import信息作比较，转换成最终的按需加载语法。

插件还能加载皮肤，原理是针对所有加载的lib里的文件，判断同级目录是否存在style目录以及style目录内是否存在对应的皮肤文件，如果存在就导入。默认皮肤名为`default`。

## 插件选项

名称|类型|必填|默认值|描述
:-:|:-:|:-:|:-:|:-:
name|`String`|`Y`|`-`|lib名称
skin|`String&#124;Array<String>`|`N`|`default`|皮肤名称，`none`表示不加载样式文件，`all`表示加载所有皮肤的样式文件，字符串表示只加载特定皮肤的样式文件，数组表示加载所有指定皮肤的样式文件

==> babel-plugin-lib-import-1.1.0.tgz: package/README.md <==
# babel-plugin-lib-import

一个能实现按需引入lib文件的babel插件。

[![Commitizen friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://commitizen.github.io/cz-cli/)

## lib类似下面的结构

```
|-- libName
    |-- lib                         // 构建后的目录
    |   |-- index.js                // package.json指定的入口文件
    |   |-- components
    |   |   |-- city-picker
    |   |   |   |-- index.js
    |   |   |-- cutover
    |   |   |   |-- index.js
    |   |   |   |-- style
    |   |   |       |-- default.js  // 样式文件，引入即可，不需要做任何处理
    |   |   |       |-- custom.js
    |   |   |-- dialog
    |   |   |   |-- index.js
    |   |   |   |-- style
    |   |   |       |-- default.js
    |   |   |       |-- custom.js
    |   |-- tools
    |       |-- easing
    |       |   |-- index.js
    |       |-- prefix
    |       |   |-- index.js
    |-- src
        |-- index.js
        |-- components
        |   |-- city-picker
        |   |   |-- README.md
        |   |   |-- index.vue
        |   |-- cutover                 // 一个目录下只存放一个组件（即只能有一个.vue文件），否则style目录下同一个皮肤不同组件的样式文件命名就会冲突（比如default皮肤的样式文件都必须命名为default.less）
        |   |   |-- README.md
        |   |   |-- index.vue
        |   |   |-- style
        |   |       |-- default.less    // cutover组件只支持`pc`或者`mobile`中的一种样式类型，所以每个皮肤只有skinname.less文件
        |   |-- dialog
        |   |   |-- README.md
        |   |   |-- index.vue
        |   |   |-- style
        |   |       |-- default.less        // 默认皮肤的mobile样式
        |   |       |-- default.pc.less     // 默认皮肤的pc样式
        |   |       |-- skinname.less
        |   |       |-- skinname.pc.less
        |-- tools
            |-- easing
            |   |-- README.md
            |   |-- index.js        // export多个变量
            |-- prefix
            |   |-- README.md
            |   |-- index.js

```

## 工作原理

```
import { Dialog, Cutover, SineEaseIn, SineEaseOut } from 'libName'
```

会被转换成

```
import { default as Dialog } from '/xxx/xx/libName/lib/components/dialog/index.js'
import { default as Cutover } from '/xxx/xx/libName/lib/components/cutover/index.js'
import { SineEaseIn, SineEaseOut } from '/xxx/xx/libName/lib/tools/easing/index.js'
import '/xxx/xx/libName/lib/components/dialog/style/default.js'
import '/xxx/xx/libName/lib/components/cutover/style/default.js'
```

插件会从lib的package.json里找到入口文件，并解析入口文件获取相关的import、export信息，然后跟项目中用到的import信息作比较，转换成最终的按需加载语法。

插件还能加载皮肤，原理是针对所有加载的lib里的文件，判断同级目录是否存在style目录以及style目录内是否存在对应的皮肤文件，如果存在就导入。默认皮肤名为`default`。

## 插件选项

名称|类型|必填|默认值|描述
:-:|:-:|:-:|:-:|:-:
name|`String`|`Y`|`-`|lib名称
path|`String`|`N`|`-`|lib目录**绝对路径**，插件默认是使用`require.resolve`来定位lib目录的，但有可能`webpack`等打包工具配置了自己的`alias`，导致插件定位的目录与打包工具定位的不一致，这时候就需要手动配置path来明确指定lib目录
skin|`String&#124;Array<String>`|`N`|`default`|皮肤名称，`none`表示不加载样式文件，`all`表示加载所有皮肤的`type`类型样式文件，字符串表示只加载特定皮肤的样式文件，数组表示加载所有指定皮肤的样式文件
type|`String`|`N`|`mobile`|支持`pc`、`mobile`和`responsive`三个值。某些组件可能需要同时支持`pc`和`mobile`样式，type指定加载哪些样式，`mobile`表示只加载手机端样式文件，`pc`表示只加载pc端样式文件，`responsive`表示需要同时加载`pc`和`mobile`样式文件。

## 示例

babel.config.js

```
module.exports = {
  presets: [
    ...
  ],
  plugins: [
    ['lib-import', {
      name: 'my-lib',
      skin: 'my-skin',
      type: 'responsive'
    }],
    ['lib-import', {
      name: 'my-lib2',
      path: '/xxx/xxx/my-lib2',
      skin: 'my-skin',
      type: 'responsive'
    }]
  ]
}
```
